@@ -4,9 +4,16 @@ from TextPreprocessing.utility import process_text
 class preprocess:
     
     def __init__(self):
-        self.__version__ = "2.2.0"
+        self.__version__ = "2.5.0"
         self.obj = process_text()
         self.start = 1
+    
+    def load_language_model(self, modal_name):
+        self.obj.set_language_modal(modal_name)
+    
+    def set_entity_ignore_list(self, ignore_list):
+        self.obj.set_entity_exclusion_list(ignore_list)
+
 
     def cleanup(self, text, end):
         text = self.obj.clear_generic_entity(text)
