@@ -12,8 +12,7 @@ from textblob import TextBlob
 class process_text:
 
     def __init__(self):
-        self.__version__ = "2.2.0"
-        self.nlp = spacy.load("en_core_web_md")
+        self.__version__ = "2.5.0"
         self.path = r".\\TextPreprocessing"
         self.abbreviations = {
             "€" : "euro",
@@ -326,6 +325,14 @@ class process_text:
             "brng": "bring"
     }
 
+    def set_entity_exclusion_list(self, list: entities=[]):
+        self.entities = entities
+        if len(self.entities)==0:
+            self.entities = ["PERSON", "ORDINAL", "CARDINAL", "DATE", "TIME", "PRODUCT"]
+
+    def set_language_modal(self, modal_name):
+        self.nlp = spacy.load(modal_name)
+
     def convert_abbreviations(self, text):
         if type(text) == str:
             for key in self.abbreviations:
@@ -367,7 +374,7 @@ class process_text:
     
     def clear_generic_entity(self, text):
         document = self.nlp(text)
-        entitites = [ent.text for ent in document.ents if ent.label_ == 'PERSON' or ent.label_ == 'ORDINAL' or ent.label_ == 'CARDINAL' or ent.label_ == 'PRODUCT' or ent.label_ == 'DATE']
+        entitites = [ent.text for ent in document.ents if ent.label_ in self.entities]
         for entity in set(entitites):
             pattern = re.sub("'", "", entity)
             text = re.sub("("+pattern+")", " ", text)
@@ -376,17 +383,6 @@ class process_text:
         
         
 
-    
-    # def clear_generic_entities(self, text):
-    #     document = self.nlp(text)
-    #     items = [ent.text for ent in document.ents if ent.label_ == 'PERSON' or ent.label_ == 'ORDINAL' or ent.label_ == 'DATE']
-    #     for char in set(items):
-    #         char = re.sub("'", "", char)
-	#         text = re.sub("("+char+")", " ", text)
-    #     text = " ".join([w for w in text.split()])
-    #     return text
-
-
     def lemetize(self, text):
         text = str(text)
         texts = []
